@@ -1,6 +1,3 @@
-library(eaf)
-context("vorob")
-
 test_that("vorob", {
   #skip_on_cran()
   test_data <- expand.grid(seq(0, 1, length.out = 51),
@@ -14,4 +11,4 @@ test_that("vorob", {
   
   expect_equal(vorobDev(x = test_data, VE = vorobT(test_data, c(1,1))$VE, reference = c(1, 1)), 0.218, tolerance = 1e-1)
 
-})
\ No newline at end of file
+})
